/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvControlCast.h"
#include "HvControlIf.h"
#include "HvSignalLine.h"
#include "HvControlVar.h"
#include "HvControlSystem.h"
#include "HvSignalBiquad.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlUnop.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_MCt1eNOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EmXLAzoM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7V4ZKRb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w9gmncr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ued1osbx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CHvaXXn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Lu7hLkQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_o1kxGJ7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eguJDk7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qRmDSVTu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_x2rlqsFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JpxqevAj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ML1b9Puz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W36lg329_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tR4nkRxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_apsz8tVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YDZ6YQ5S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3l3XbX6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3GQu4uKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KmzdO5jH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dLdFr6NU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S59jtLeE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EYkIWKUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cwGYZVr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M3p9RjFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qght2VXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C6SPTL0f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UInfozDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YfIIfiE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5fzrw2EJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HEXK3t5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_g649xj9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zZ7x4VvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tjd0DAya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KFHnJ91C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1jnVT4X8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uim3rZpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B79UuABd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iQwTuZmY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MVqdi03B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NJFM3csX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LPTxCPZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RYaQUrBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WWSFjHjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zCod6LGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aGkmOKJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K5IKs9x8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DnMdh2r1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ufwwsGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C6mFOSQv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uCFFQmHq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cYpKU399_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hNfzcEJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XqrrW6rp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C8LPgKDC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_O4cMsHgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_If40ykhZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ree5cTlM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_07xsQ0O3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sOTW9ylX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IDfIMGRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8kpXttAa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LunYUGBL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qbpb0r8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A5BeUsQ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RaGWgXW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yNae5tjz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nTA2Ja8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4dNM3gpz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8xvu4shx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hSTJPnZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tzcG5HEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sVRlq0TA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aEfZAGvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G7vhMCb8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oytrQjko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4bUIljzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4bleImbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_s9Pj5Rvg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3OdPbKKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TDpIw5pE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CE1tdyXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oSfCLX0g_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_A5LXP7IR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4bCLSFyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hlfZvk7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XIyMdBng_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_MVAlIBnO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yQHrDHTI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HD7K6GEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WJwqthty_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_b4XvjEF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_h1F9CcER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3Izv09YN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IUH3r1Y3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vx61vz1D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SXFtMYft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gTSQ7H1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bQke2BZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WRTPqGXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ogD9ukWi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_84Q0nEwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9gNXVRtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ktMyW19N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j7QtGvQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IZwr7tMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W6e3Eo0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5WAbE0bn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ZVcz86bl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hQ0kANNn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7j8CLKaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oCs9jLpL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ulBTkFBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SVNiR4KG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_noypLz82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lOi8bf7Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H3B101N0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r90NGmIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iEWfHdrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ovTejgFg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_okmxx322_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_thhW0TXk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m3Q0qUFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ic9jgiY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Mu76YY8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sFQ83uaE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wky58U50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GRKCwlwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9es1qZhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OY2feIdr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NKMk9OmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tzHgbS8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cwkwWN6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_smK33ZPk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F5iCPMHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dyf9qrVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8jVLOcqK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_szCw0xzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8xX5MOLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PKzh8Smd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F4uloD9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qf7Yg6Pg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eW3iui7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QetYCrpQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dQKwAKZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jtJYltrp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pwlAq2In_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wuEl8Xql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KMCYGLDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_abwVx7Qg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OAtIhmLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ngB0KmiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s5MVwZHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_esvynVWb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wmdd337A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M3qTJSs0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S6g9N9cY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oSPLUm8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Lum4cI0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ede5nkZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PZk4yHra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mZxLm10V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gf6MlPwl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z3IWqPji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_whXueLo0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1v1yFzYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qqoCOMro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PJxmJpQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AAcQcADH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NC6kyKWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bIi8Ua57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rO7WdfRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DJS7J870_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hx72NTo5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PHgECsya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UwYHFfQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bWNw8mU6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kOWvWRSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WVtQ6bgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gWxG3H99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Zh6vIgo0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9B9Ntk1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_t0BIsob1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fTMqa8Zx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xNF3gcLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L4doZIOO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hp01rg6O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Y2dz6pA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pOnELfBG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ahzZreHB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o5vJum8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FLyOawQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UtJvQG8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_grG3RZAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WTmLtXL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IDy953eH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cgBNMeSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wMKWCOJI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y35QkgyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hz7gA95o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EomT7Fkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cV5cCtS9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G4UYiRrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DvChQuxk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QodfdHS6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zILsXqA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cDBD4SYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6D1ATCFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IgIwnHne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L6KLsOrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RVMWducb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NveWIXLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OXMWMxDC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tAb0gqjt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7PQVhklk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ggS1VoWT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gmQZvJHU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9UmmQ0Mn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qzgMkvk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8x2JO0qt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ta698wmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pbp22mFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oCjNfcsI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c0NgEBPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QH2GaZzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QMdu7Qd9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PbdzJRa4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4c3Zrzsv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oGo1nGLj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bOUOkGRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SDJ8WT3O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rbIiiP9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9migpgiZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xZPkSkz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ibNapkzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8Bq46fMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZNfaTFIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8fi1mahs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1mVURbtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7fxTbt6v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6ufKFXk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_elhwyX3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JNhZwSDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5gq9lttR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IWxB03S7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VRJjlXTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IvV2Rrve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4M0tSsKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P6vh0uUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gi4fCoA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1WgGiLuS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_paw4q5aF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Tjf84Cv5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LtiECarO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t3qWhUoL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tydNPxP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kj9jaYbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uzPyWBSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DVdZ6fkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n2NCr5Nq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dGbwvhm5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3wK6O2ii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9ewa27y9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dZ8gNZjK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xNod0mcp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ul6QYKz9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_2LwgXpSY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_i5SlIDFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_G0U2k0LZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6n1ptZWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JTZ1IKB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iMQXJMJD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RVvEgI1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RHx4wnkZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SJbbdtvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o2KAeLMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cYhJpWNk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l9q6fTCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d5S0zB9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YcbpUTXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CpDev5Jd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Sglm63tX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8pHIafrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v2YLM6h5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ButjbcKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6xe6JzxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OlNk12Bg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_akQu7LYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hOW9wh6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RFGZDtgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FR1Umxle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QmCRSzeT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2scni3eZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9cuno8xQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9WifW4f4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g9OQVF2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6cBfTcEU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kWBMHcXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ucwt6cVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ADlKmKMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k6Y85uDn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Q0QUnJW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_roc9Kbeb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_syfmOWEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5Fmj0pWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tdKkTL7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_exsayOmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0sVLPEJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_twajeKBV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5KuNCxM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_98Sf69L1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S11Sq86Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P8Puzn47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dSuFpHIP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g8obLLTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WCwaKddX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_o2pWlvXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xSoyV3Hd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wnd1rofi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dhUemtNy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TIHm8NIx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qob8qhzz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7WYzPY8A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Zs5RdFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s0wNSLqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gTlZbC3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bQSbnWMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ww9a1e2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4z53bMMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_INhmreY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aWmEW933_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AQUWLiF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_voXTA9H7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pync9tSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XOk9lZoe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CmOeu0aS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T1uoPUzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_spV4zaQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1iP3jMtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ET9V8t2n_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_20wNMU4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OqfnMYBG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dkDxFYUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v9pPmzoX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_M3ZerbGm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BPhwZmBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_s36vaIsF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_B7oP4RX9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_o92EDTVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3YjHqHI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3Nuh3SOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HNGv5Ty1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ehAQ7LRY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wJPEZOyG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_V7fm0Wqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9K6L0IXh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SJMGHCpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JAgsWxMT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Blo1iSJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4l982FSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uBSS2XWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Mwe8hHal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Wtq38Jfp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qpoz1FcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oyf19TSz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_is2R2ysG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pNLIwXU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tj45sKgl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CgYMEonz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_D60M37za_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QLFfMvzL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6lFpXUr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3IQJwOYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TOzlB9zO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bJM9ku1p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6DgZizDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YXlIdWLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lHR2RaGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TU7ZtCr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VnJEuoBJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WrBP4Y6L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dZTfQpTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qBr0ZQF7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F3MvYVau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NeTm1lzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DyalfqH1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AyHfsWdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qTPBWvD0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PPhVPuVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XT9557qb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JTLElthr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bzr6qJHt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CBNm1D3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cIZ5p8T6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_he52eyoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_luxA17G8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NkyXPQ4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PhFfDImX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vG5wqtPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aqgp1Hbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DV5zqde0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JnJ7qzWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HzvpsBRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WStABlMm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6GKJKxCV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pro0Vobo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GJ6yu2Ss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zJaYLo8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4b1jKPKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hm1Rlx1a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WXFcTegE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zgiVoHRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eqpsCsQg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M4OqL4ic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JUdpcGWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ycRXuube_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NuLZHSgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yGkQMEJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fz85ZR8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HAMcR7DU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wgID9Q00_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3qRDaBcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QGysqANR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AGIxSVFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5U1OEPsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PNjhWMVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SS4MzIdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eWr6TIsq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kCbH2MXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UwrOZwO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_94JpsZbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6HVVBZN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PHLmQFA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_82yXtScm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Py2B8oN6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ACWcDcJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yavj0bIj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xtlgIGhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rbtlhECx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aGhQqfWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OEKg4ZMV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RBF5SVAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pNfINrWG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Fj09nh3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6GNB6Owk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8ugEX6Fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D9sNzMbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_scBa1ahB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LfK3fjCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iKLgb07M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AxddfZ9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mVQuTqqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OlFtt4Ed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xf5dnuZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JdlFCsfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rowX8NdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uH4shFSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s06HyyhY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6MHWaRcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1j0vkMGZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ETNSNvCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mczD6lIC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Ty0f5sg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SrtTZPab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MFvw7s47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kRjr5QcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HlhGoBAu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lZcqsGo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eVTeAKff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PVzbzDCQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w6oaRhIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8vZy5LTu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WIartZW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zN5Ekav1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iUg9XnRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ENQNBbCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_huIq7Q6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZZf0reAk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i38YuzND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ahh2pa20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OAS48UND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wA0kOFoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l3hcsEwC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pzT1TJpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lxxYYLIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fBfwri5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ODwWcLRq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_az4wfEwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qPPk37NN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ElyB4L1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y55NAcEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F0KbgIKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p84ojCv6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mV6cF0O5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xRDoULzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pP9sFdnL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pFM0GBGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fQnjgvmO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_35ci5R7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vJQwOwxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WzwgyqxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ojj5ChFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DIvPdGgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FTbHIHeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6hpqstFx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ncl7HA05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_baVxFUhW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8jPS2AjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JwLRJIaT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vb1ZLfW7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uxYd9p29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLZXQbzQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fviZoMCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iqr5wKNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4LgyNVq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vgK0AMQR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nVaw3lDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q93CMOmE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4YJ2XG0J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MqjovD53_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T9MkDZYd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cJ1Mja9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IVdvziQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FSkf5zXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yv8YMCME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5bWA2RgZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_taECnX9N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_d7HZyxUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cZ5DXqYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xyiUTJXB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LjdAYhXC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NSLgc72H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lWBc3aWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_89llZr5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5WtEBxwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_89cx69PA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OX4QiFIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qaD9Lnjd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kT5owaMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DEtwM8ay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JBRoY43W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dfp1DLgj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F6jHrbc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0aVwXfDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CJ9l0RS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s8NKbcQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RNKu9GQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lm40okWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_88EN9vcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6yvLC2Iw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8kb5FU9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Uz8B1tCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Xv8LyGyT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Qt5XWqfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_44Q0ZM5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_B6WlgAmF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P7cuA8NF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XixLcU24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_M6qVIi6e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FZJ91Nqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9x3KE4yr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oA3v9CYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o7c1fxJ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_O1c8Kt3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gWzObvec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2TJ61AFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mNrREZ7X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IUwlfN7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3TIzdniJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xWrPFnXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VXjlQxSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WOISfsi9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HyrmMXVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0QzKyuj7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_X2V4wATS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_g1qsdEsi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tUSj4xRn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2PFZpol9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EQVetrNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nST7NwrE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FcnzVrtZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_pgQQBMH1;
  SignalLine sLine_r6xiIwcH;
  SignalLine sLine_knf87jTE;
  SignalLine sLine_jkX8pWd3;
  SignalLine sLine_L4RZ2g1F;
  SignalBiquad sBiquad_s_jC0mNb1o;
  SignalLine sLine_u3t0R9xr;
  SignalLine sLine_eLbD7VN0;
  SignalLine sLine_hXm7kGbu;
  SignalLine sLine_laCV4pAV;
  SignalBiquad sBiquad_s_4ucADfyy;
  SignalLine sLine_bTc7Mk7V;
  SignalLine sLine_EiZU3hcH;
  SignalLine sLine_mfqpsxFo;
  SignalLine sLine_QLYH2A29;
  SignalLine sLine_qk89EJtr;
  SignalBiquad sBiquad_s_gE3cUscl;
  SignalLine sLine_doXSiWGJ;
  SignalLine sLine_3oG0g0JV;
  SignalLine sLine_yyJeHcEf;
  SignalLine sLine_yDwuL3KH;
  SignalLine sLine_XolpV6U9;
  SignalBiquad sBiquad_s_vlkzHD5M;
  SignalLine sLine_nWumo2KL;
  SignalLine sLine_4UfskI8D;
  SignalLine sLine_1RvMZ9WL;
  SignalLine sLine_AaYjNJdF;
  SignalBiquad sBiquad_s_EsqsyHhA;
  SignalLine sLine_vRIIGk8F;
  SignalLine sLine_me9udPJU;
  SignalLine sLine_iamKpxWx;
  SignalLine sLine_ktZ6RwQF;
  SignalLine sLine_HTRSDykD;
  SignalBiquad sBiquad_s_90m0DUGd;
  ControlVar cVar_MCt1eNOB;
  ControlVar cVar_EmXLAzoM;
  ControlVar cVar_7V4ZKRb3;
  ControlVar cVar_w9gmncr6;
  ControlSlice cSlice_CHvaXXn6;
  ControlVar cVar_Lu7hLkQQ;
  ControlVar cVar_eguJDk7U;
  ControlIf cIf_qRmDSVTu;
  ControlIf cIf_x2rlqsFn;
  ControlBinop cBinop_ML1b9Puz;
  ControlBinop cBinop_W36lg329;
  ControlBinop cBinop_YDZ6YQ5S;
  ControlBinop cBinop_3l3XbX6k;
  ControlBinop cBinop_KmzdO5jH;
  ControlIf cIf_dLdFr6NU;
  ControlBinop cBinop_S59jtLeE;
  ControlBinop cBinop_EYkIWKUS;
  ControlBinop cBinop_M3p9RjFE;
  ControlBinop cBinop_Qght2VXl;
  ControlBinop cBinop_C6SPTL0f;
  ControlVar cVar_g649xj9b;
  ControlIf cIf_zZ7x4VvT;
  ControlIf cIf_tjd0DAya;
  ControlBinop cBinop_1jnVT4X8;
  ControlBinop cBinop_uim3rZpk;
  ControlBinop cBinop_MVqdi03B;
  ControlBinop cBinop_NJFM3csX;
  ControlBinop cBinop_RYaQUrBh;
  ControlIf cIf_WWSFjHjP;
  ControlBinop cBinop_zCod6LGa;
  ControlBinop cBinop_aGkmOKJF;
  ControlBinop cBinop_DnMdh2r1;
  ControlBinop cBinop_5ufwwsGL;
  ControlBinop cBinop_C6mFOSQv;
  ControlVar cVar_C8LPgKDC;
  ControlIf cIf_O4cMsHgb;
  ControlIf cIf_If40ykhZ;
  ControlBinop cBinop_07xsQ0O3;
  ControlBinop cBinop_sOTW9ylX;
  ControlBinop cBinop_LunYUGBL;
  ControlBinop cBinop_qbpb0r8Q;
  ControlBinop cBinop_RaGWgXW6;
  ControlIf cIf_yNae5tjz;
  ControlBinop cBinop_nTA2Ja8m;
  ControlBinop cBinop_4dNM3gpz;
  ControlBinop cBinop_hSTJPnZO;
  ControlBinop cBinop_tzcG5HEA;
  ControlBinop cBinop_sVRlq0TA;
  ControlIf cIf_4bleImbX;
  ControlSlice cSlice_3OdPbKKU;
  ControlVar cVar_TDpIw5pE;
  ControlSlice cSlice_A5LXP7IR;
  ControlVar cVar_4bCLSFyI;
  ControlSlice cSlice_MVAlIBnO;
  ControlVar cVar_yQHrDHTI;
  ControlSlice cSlice_b4XvjEF6;
  ControlVar cVar_h1F9CcER;
  ControlBinop cBinop_ktMyW19N;
  ControlBinop cBinop_IZwr7tMO;
  ControlBinop cBinop_W6e3Eo0O;
  ControlBinop cBinop_hQ0kANNn;
  ControlBinop cBinop_7j8CLKaC;
  ControlBinop cBinop_oCs9jLpL;
  ControlBinop cBinop_ulBTkFBw;
  ControlBinop cBinop_SVNiR4KG;
  ControlVar cVar_noypLz82;
  ControlBinop cBinop_lOi8bf7Q;
  ControlBinop cBinop_H3B101N0;
  ControlBinop cBinop_r90NGmIy;
  ControlBinop cBinop_iEWfHdrY;
  ControlBinop cBinop_ovTejgFg;
  ControlBinop cBinop_okmxx322;
  ControlBinop cBinop_thhW0TXk;
  ControlBinop cBinop_ic9jgiY4;
  ControlVar cVar_Mu76YY8J;
  ControlVar cVar_sFQ83uaE;
  ControlBinop cBinop_cwkwWN6T;
  ControlBinop cBinop_smK33ZPk;
  ControlBinop cBinop_F5iCPMHn;
  ControlBinop cBinop_8jVLOcqK;
  ControlBinop cBinop_szCw0xzK;
  ControlBinop cBinop_8xX5MOLP;
  ControlBinop cBinop_PKzh8Smd;
  ControlBinop cBinop_F4uloD9d;
  ControlBinop cBinop_Qf7Yg6Pg;
  ControlBinop cBinop_PZk4yHra;
  ControlBinop cBinop_gf6MlPwl;
  ControlBinop cBinop_Z3IWqPji;
  ControlBinop cBinop_qqoCOMro;
  ControlBinop cBinop_PJxmJpQT;
  ControlBinop cBinop_AAcQcADH;
  ControlBinop cBinop_NC6kyKWv;
  ControlBinop cBinop_bIi8Ua57;
  ControlBinop cBinop_rO7WdfRM;
  ControlBinop cBinop_DJS7J870;
  ControlBinop cBinop_PHgECsya;
  ControlVar cVar_UwYHFfQK;
  ControlVar cVar_bWNw8mU6;
  ControlVar cVar_kOWvWRSi;
  ControlBinop cBinop_xNF3gcLg;
  ControlBinop cBinop_L4doZIOO;
  ControlBinop cBinop_Hp01rg6O;
  ControlBinop cBinop_pOnELfBG;
  ControlBinop cBinop_ahzZreHB;
  ControlBinop cBinop_o5vJum8z;
  ControlBinop cBinop_FLyOawQe;
  ControlBinop cBinop_UtJvQG8f;
  ControlBinop cBinop_RVMWducb;
  ControlBinop cBinop_OXMWMxDC;
  ControlBinop cBinop_tAb0gqjt;
  ControlBinop cBinop_gmQZvJHU;
  ControlBinop cBinop_9UmmQ0Mn;
  ControlBinop cBinop_qzgMkvk1;
  ControlBinop cBinop_8x2JO0qt;
  ControlBinop cBinop_ta698wmq;
  ControlBinop cBinop_oCjNfcsI;
  ControlBinop cBinop_QH2GaZzG;
  ControlBinop cBinop_QMdu7Qd9;
  ControlBinop cBinop_4c3Zrzsv;
  ControlBinop cBinop_oGo1nGLj;
  ControlBinop cBinop_bOUOkGRN;
  ControlBinop cBinop_rbIiiP9c;
  ControlVar cVar_9migpgiZ;
  ControlVar cVar_xZPkSkz8;
  ControlVar cVar_ibNapkzx;
  ControlBinop cBinop_elhwyX3o;
  ControlBinop cBinop_JNhZwSDm;
  ControlBinop cBinop_5gq9lttR;
  ControlBinop cBinop_VRJjlXTj;
  ControlBinop cBinop_IvV2Rrve;
  ControlBinop cBinop_4M0tSsKy;
  ControlBinop cBinop_P6vh0uUd;
  ControlBinop cBinop_Gi4fCoA0;
  ControlBinop cBinop_1WgGiLuS;
  ControlBinop cBinop_3wK6O2ii;
  ControlBinop cBinop_dZ8gNZjK;
  ControlBinop cBinop_xNod0mcp;
  SignalVarf sVarf_wCWs1TP0;
  SignalVarf sVarf_qaedgNcM;
  SignalVarf sVarf_HHYTZEoj;
  ControlSlice cSlice_2LwgXpSY;
  ControlVar cVar_i5SlIDFm;
  ControlVar cVar_6n1ptZWV;
  ControlIf cIf_JTZ1IKB5;
  ControlIf cIf_iMQXJMJD;
  ControlBinop cBinop_RHx4wnkZ;
  ControlBinop cBinop_SJbbdtvy;
  ControlBinop cBinop_l9q6fTCY;
  ControlBinop cBinop_d5S0zB9W;
  ControlBinop cBinop_CpDev5Jd;
  ControlIf cIf_Sglm63tX;
  ControlBinop cBinop_8pHIafrG;
  ControlBinop cBinop_v2YLM6h5;
  ControlBinop cBinop_6xe6JzxM;
  ControlBinop cBinop_OlNk12Bg;
  ControlBinop cBinop_akQu7LYv;
  ControlVar cVar_2scni3eZ;
  ControlIf cIf_9cuno8xQ;
  ControlIf cIf_9WifW4f4;
  ControlBinop cBinop_6cBfTcEU;
  ControlBinop cBinop_kWBMHcXi;
  ControlBinop cBinop_k6Y85uDn;
  ControlBinop cBinop_0Q0QUnJW;
  ControlBinop cBinop_syfmOWEJ;
  ControlIf cIf_5Fmj0pWp;
  ControlBinop cBinop_tdKkTL7N;
  ControlBinop cBinop_exsayOmx;
  ControlBinop cBinop_twajeKBV;
  ControlBinop cBinop_5KuNCxM6;
  ControlBinop cBinop_98Sf69L1;
  ControlVar cVar_WCwaKddX;
  ControlIf cIf_o2pWlvXe;
  ControlIf cIf_xSoyV3Hd;
  ControlBinop cBinop_dhUemtNy;
  ControlBinop cBinop_TIHm8NIx;
  ControlBinop cBinop_8Zs5RdFO;
  ControlBinop cBinop_s0wNSLqm;
  ControlBinop cBinop_bQSbnWMO;
  ControlIf cIf_Ww9a1e2m;
  ControlBinop cBinop_4z53bMMx;
  ControlBinop cBinop_INhmreY7;
  ControlBinop cBinop_AQUWLiF2;
  ControlBinop cBinop_voXTA9H7;
  ControlBinop cBinop_pync9tSR;
  ControlIf cIf_1iP3jMtq;
  ControlSlice cSlice_20wNMU4B;
  ControlVar cVar_OqfnMYBG;
  ControlSlice cSlice_M3ZerbGm;
  ControlVar cVar_BPhwZmBm;
  ControlSlice cSlice_o92EDTVB;
  ControlVar cVar_3YjHqHI1;
  ControlSlice cSlice_ehAQ7LRY;
  ControlVar cVar_wJPEZOyG;
  ControlBinop cBinop_oyf19TSz;
  ControlBinop cBinop_pNLIwXU3;
  ControlBinop cBinop_Tj45sKgl;
  ControlBinop cBinop_QLFfMvzL;
  ControlBinop cBinop_6lFpXUr5;
  ControlBinop cBinop_3IQJwOYo;
  ControlBinop cBinop_TOzlB9zO;
  ControlBinop cBinop_bJM9ku1p;
  ControlVar cVar_6DgZizDj;
  ControlBinop cBinop_YXlIdWLo;
  ControlBinop cBinop_lHR2RaGG;
  ControlBinop cBinop_TU7ZtCr5;
  ControlBinop cBinop_VnJEuoBJ;
  ControlBinop cBinop_WrBP4Y6L;
  ControlBinop cBinop_dZTfQpTr;
  ControlBinop cBinop_qBr0ZQF7;
  ControlBinop cBinop_NeTm1lzK;
  ControlVar cVar_DyalfqH1;
  ControlVar cVar_AyHfsWdy;
  ControlBinop cBinop_cIZ5p8T6;
  ControlBinop cBinop_he52eyoA;
  ControlBinop cBinop_luxA17G8;
  ControlBinop cBinop_PhFfDImX;
  ControlBinop cBinop_vG5wqtPa;
  ControlBinop cBinop_aqgp1Hbf;
  ControlBinop cBinop_DV5zqde0;
  ControlBinop cBinop_JnJ7qzWA;
  ControlBinop cBinop_HzvpsBRu;
  ControlBinop cBinop_3qRDaBcg;
  ControlBinop cBinop_AGIxSVFf;
  ControlBinop cBinop_5U1OEPsD;
  ControlBinop cBinop_eWr6TIsq;
  ControlBinop cBinop_kCbH2MXd;
  ControlBinop cBinop_UwrOZwO0;
  ControlBinop cBinop_94JpsZbd;
  ControlBinop cBinop_6HVVBZN5;
  ControlBinop cBinop_PHLmQFA7;
  ControlBinop cBinop_82yXtScm;
  ControlBinop cBinop_ACWcDcJa;
  ControlVar cVar_yavj0bIj;
  ControlVar cVar_xtlgIGhj;
  ControlVar cVar_rbtlhECx;
  ControlBinop cBinop_8ugEX6Fw;
  ControlBinop cBinop_D9sNzMbM;
  ControlBinop cBinop_scBa1ahB;
  ControlBinop cBinop_iKLgb07M;
  ControlBinop cBinop_AxddfZ9c;
  ControlBinop cBinop_mVQuTqqm;
  ControlBinop cBinop_OlFtt4Ed;
  ControlBinop cBinop_xf5dnuZy;
  ControlBinop cBinop_8vZy5LTu;
  ControlBinop cBinop_zN5Ekav1;
  ControlBinop cBinop_iUg9XnRW;
  ControlBinop cBinop_ZZf0reAk;
  ControlBinop cBinop_i38YuzND;
  ControlBinop cBinop_ahh2pa20;
  ControlBinop cBinop_OAS48UND;
  ControlBinop cBinop_wA0kOFoa;
  ControlBinop cBinop_pzT1TJpw;
  ControlBinop cBinop_fBfwri5s;
  ControlBinop cBinop_ODwWcLRq;
  ControlBinop cBinop_qPPk37NN;
  ControlBinop cBinop_5ElyB4L1;
  ControlBinop cBinop_Y55NAcEn;
  ControlBinop cBinop_p84ojCv6;
  ControlVar cVar_mV6cF0O5;
  ControlVar cVar_xRDoULzp;
  ControlVar cVar_pP9sFdnL;
  ControlBinop cBinop_DIvPdGgA;
  ControlBinop cBinop_FTbHIHeA;
  ControlBinop cBinop_6hpqstFx;
  ControlBinop cBinop_baVxFUhW;
  ControlBinop cBinop_8jPS2AjS;
  ControlBinop cBinop_JwLRJIaT;
  ControlBinop cBinop_Vb1ZLfW7;
  ControlBinop cBinop_uxYd9p29;
  ControlBinop cBinop_lLZXQbzQ;
  ControlBinop cBinop_IVdvziQD;
  ControlBinop cBinop_yv8YMCME;
  ControlBinop cBinop_5bWA2RgZ;
  SignalVarf sVarf_qHnSMGpS;
  SignalVarf sVarf_Lzx28c4B;
  SignalVarf sVarf_eKImh4nO;
  SignalVarf sVarf_dS0GJuSZ;
  SignalVarf sVarf_xF0n5O8G;
  SignalVarf sVarf_ZtKBZZCO;
  SignalVarf sVarf_9fPTsxO3;
  SignalVarf sVarf_2sUXdkIQ;
  SignalVarf sVarf_UWQ3dLgE;
  ControlVar cVar_taECnX9N;
  ControlVar cVar_d7HZyxUB;
  ControlBinop cBinop_89llZr5m;
  ControlBinop cBinop_5WtEBxwy;
  ControlBinop cBinop_89cx69PA;
  ControlBinop cBinop_qaD9Lnjd;
  ControlBinop cBinop_kT5owaMj;
  ControlBinop cBinop_DEtwM8ay;
  ControlBinop cBinop_JBRoY43W;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
