/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_pgQQBMH1);
  numBytes += sLine_init(&sLine_r6xiIwcH);
  numBytes += sLine_init(&sLine_knf87jTE);
  numBytes += sLine_init(&sLine_jkX8pWd3);
  numBytes += sLine_init(&sLine_L4RZ2g1F);
  numBytes += sBiquad_init(&sBiquad_s_jC0mNb1o);
  numBytes += sLine_init(&sLine_u3t0R9xr);
  numBytes += sLine_init(&sLine_eLbD7VN0);
  numBytes += sLine_init(&sLine_hXm7kGbu);
  numBytes += sLine_init(&sLine_laCV4pAV);
  numBytes += sBiquad_init(&sBiquad_s_4ucADfyy);
  numBytes += sLine_init(&sLine_bTc7Mk7V);
  numBytes += sLine_init(&sLine_EiZU3hcH);
  numBytes += sLine_init(&sLine_mfqpsxFo);
  numBytes += sLine_init(&sLine_QLYH2A29);
  numBytes += sLine_init(&sLine_qk89EJtr);
  numBytes += sBiquad_init(&sBiquad_s_gE3cUscl);
  numBytes += sLine_init(&sLine_doXSiWGJ);
  numBytes += sLine_init(&sLine_3oG0g0JV);
  numBytes += sLine_init(&sLine_yyJeHcEf);
  numBytes += sLine_init(&sLine_yDwuL3KH);
  numBytes += sLine_init(&sLine_XolpV6U9);
  numBytes += sBiquad_init(&sBiquad_s_vlkzHD5M);
  numBytes += sLine_init(&sLine_nWumo2KL);
  numBytes += sLine_init(&sLine_4UfskI8D);
  numBytes += sLine_init(&sLine_1RvMZ9WL);
  numBytes += sLine_init(&sLine_AaYjNJdF);
  numBytes += sBiquad_init(&sBiquad_s_EsqsyHhA);
  numBytes += sLine_init(&sLine_vRIIGk8F);
  numBytes += sLine_init(&sLine_me9udPJU);
  numBytes += sLine_init(&sLine_iamKpxWx);
  numBytes += sLine_init(&sLine_ktZ6RwQF);
  numBytes += sLine_init(&sLine_HTRSDykD);
  numBytes += sBiquad_init(&sBiquad_s_90m0DUGd);
  numBytes += cVar_init_f(&cVar_MCt1eNOB, 0.0f);
  numBytes += cVar_init_f(&cVar_EmXLAzoM, 0.0f);
  numBytes += cVar_init_f(&cVar_7V4ZKRb3, 0.0f);
  numBytes += cVar_init_f(&cVar_w9gmncr6, 0.0f);
  numBytes += cSlice_init(&cSlice_CHvaXXn6, 1, -1);
  numBytes += cVar_init_f(&cVar_Lu7hLkQQ, 1337.0f);
  numBytes += cVar_init_f(&cVar_eguJDk7U, 0.0f);
  numBytes += cIf_init(&cIf_qRmDSVTu, false);
  numBytes += cIf_init(&cIf_x2rlqsFn, false);
  numBytes += cBinop_init(&cBinop_ML1b9Puz, 0.0f); // __pow
  numBytes += cIf_init(&cIf_dLdFr6NU, false);
  numBytes += cBinop_init(&cBinop_M3p9RjFE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Qght2VXl, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_C6SPTL0f, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_g649xj9b, 0.0f);
  numBytes += cIf_init(&cIf_zZ7x4VvT, false);
  numBytes += cIf_init(&cIf_tjd0DAya, false);
  numBytes += cBinop_init(&cBinop_1jnVT4X8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_WWSFjHjP, false);
  numBytes += cBinop_init(&cBinop_DnMdh2r1, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_5ufwwsGL, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_C6mFOSQv, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_C8LPgKDC, 0.0f);
  numBytes += cIf_init(&cIf_O4cMsHgb, false);
  numBytes += cIf_init(&cIf_If40ykhZ, false);
  numBytes += cBinop_init(&cBinop_07xsQ0O3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_yNae5tjz, false);
  numBytes += cBinop_init(&cBinop_hSTJPnZO, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_tzcG5HEA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_sVRlq0TA, -15.0f); // __eq
  numBytes += cIf_init(&cIf_4bleImbX, false);
  numBytes += cSlice_init(&cSlice_3OdPbKKU, 1, -1);
  numBytes += cVar_init_f(&cVar_TDpIw5pE, 0.0f);
  numBytes += cSlice_init(&cSlice_A5LXP7IR, 1, -1);
  numBytes += cVar_init_f(&cVar_4bCLSFyI, 0.0f);
  numBytes += cSlice_init(&cSlice_MVAlIBnO, 1, -1);
  numBytes += cVar_init_f(&cVar_yQHrDHTI, 0.0f);
  numBytes += cSlice_init(&cSlice_b4XvjEF6, 1, -1);
  numBytes += cVar_init_f(&cVar_h1F9CcER, 0.313f);
  numBytes += cBinop_init(&cBinop_IZwr7tMO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_W6e3Eo0O, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_noypLz82, 0.0f);
  numBytes += cVar_init_f(&cVar_Mu76YY8J, 1337.0f);
  numBytes += cVar_init_f(&cVar_sFQ83uaE, 0.3f);
  numBytes += cBinop_init(&cBinop_smK33ZPk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_szCw0xzK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8xX5MOLP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PKzh8Smd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F4uloD9d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qf7Yg6Pg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gf6MlPwl, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Z3IWqPji, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_UwYHFfQK, 0.0f);
  numBytes += cVar_init_f(&cVar_bWNw8mU6, 1337.0f);
  numBytes += cVar_init_f(&cVar_kOWvWRSi, 0.313f);
  numBytes += cBinop_init(&cBinop_L4doZIOO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ahzZreHB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_o5vJum8z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FLyOawQe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UtJvQG8f, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OXMWMxDC, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_tAb0gqjt, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_9migpgiZ, 0.0f);
  numBytes += cVar_init_f(&cVar_xZPkSkz8, 1037.0f);
  numBytes += cVar_init_f(&cVar_ibNapkzx, 0.4f);
  numBytes += cBinop_init(&cBinop_JNhZwSDm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IvV2Rrve, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4M0tSsKy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_P6vh0uUd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Gi4fCoA0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1WgGiLuS, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wCWs1TP0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qaedgNcM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HHYTZEoj, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_2LwgXpSY, 1, -1);
  numBytes += cVar_init_f(&cVar_i5SlIDFm, 1337.0f);
  numBytes += cVar_init_f(&cVar_6n1ptZWV, 0.0f);
  numBytes += cIf_init(&cIf_JTZ1IKB5, false);
  numBytes += cIf_init(&cIf_iMQXJMJD, false);
  numBytes += cBinop_init(&cBinop_RHx4wnkZ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Sglm63tX, false);
  numBytes += cBinop_init(&cBinop_6xe6JzxM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_OlNk12Bg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_akQu7LYv, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_2scni3eZ, 0.0f);
  numBytes += cIf_init(&cIf_9cuno8xQ, false);
  numBytes += cIf_init(&cIf_9WifW4f4, false);
  numBytes += cBinop_init(&cBinop_6cBfTcEU, 0.0f); // __pow
  numBytes += cIf_init(&cIf_5Fmj0pWp, false);
  numBytes += cBinop_init(&cBinop_twajeKBV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_5KuNCxM6, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_98Sf69L1, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_WCwaKddX, 0.0f);
  numBytes += cIf_init(&cIf_o2pWlvXe, false);
  numBytes += cIf_init(&cIf_xSoyV3Hd, false);
  numBytes += cBinop_init(&cBinop_dhUemtNy, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Ww9a1e2m, false);
  numBytes += cBinop_init(&cBinop_AQUWLiF2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_voXTA9H7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_pync9tSR, -15.0f); // __eq
  numBytes += cIf_init(&cIf_1iP3jMtq, false);
  numBytes += cSlice_init(&cSlice_20wNMU4B, 1, -1);
  numBytes += cVar_init_f(&cVar_OqfnMYBG, 0.0f);
  numBytes += cSlice_init(&cSlice_M3ZerbGm, 1, -1);
  numBytes += cVar_init_f(&cVar_BPhwZmBm, 0.0f);
  numBytes += cSlice_init(&cSlice_o92EDTVB, 1, -1);
  numBytes += cVar_init_f(&cVar_3YjHqHI1, 0.0f);
  numBytes += cSlice_init(&cSlice_ehAQ7LRY, 1, -1);
  numBytes += cVar_init_f(&cVar_wJPEZOyG, 0.313f);
  numBytes += cBinop_init(&cBinop_pNLIwXU3, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Tj45sKgl, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_6DgZizDj, 0.0f);
  numBytes += cVar_init_f(&cVar_DyalfqH1, 1337.0f);
  numBytes += cVar_init_f(&cVar_AyHfsWdy, 0.3f);
  numBytes += cBinop_init(&cBinop_he52eyoA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vG5wqtPa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aqgp1Hbf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DV5zqde0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JnJ7qzWA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HzvpsBRu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AGIxSVFf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_5U1OEPsD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_yavj0bIj, 0.0f);
  numBytes += cVar_init_f(&cVar_xtlgIGhj, 1337.0f);
  numBytes += cVar_init_f(&cVar_rbtlhECx, 0.313f);
  numBytes += cBinop_init(&cBinop_D9sNzMbM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AxddfZ9c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mVQuTqqm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OlFtt4Ed, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xf5dnuZy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zN5Ekav1, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_iUg9XnRW, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_mV6cF0O5, 0.0f);
  numBytes += cVar_init_f(&cVar_xRDoULzp, 1037.0f);
  numBytes += cVar_init_f(&cVar_pP9sFdnL, 0.4f);
  numBytes += cBinop_init(&cBinop_FTbHIHeA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8jPS2AjS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JwLRJIaT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Vb1ZLfW7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uxYd9p29, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lLZXQbzQ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qHnSMGpS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Lzx28c4B, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eKImh4nO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dS0GJuSZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xF0n5O8G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZtKBZZCO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9fPTsxO3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2sUXdkIQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UWQ3dLgE, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_taECnX9N, 5705.6f);
  numBytes += cVar_init_f(&cVar_d7HZyxUB, 313.3f);
  numBytes += cBinop_init(&cBinop_89llZr5m, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_5WtEBxwy, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_89cx69PA, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_88EN9vcs_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8kb5FU9S_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6yvLC2Iw_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FcnzVrtZ_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qt5XWqfZ_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_44Q0ZM5T_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Uz8B1tCg_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xv8LyGyT_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B6WlgAmF_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FZJ91Nqi_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M6qVIi6e_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XixLcU24_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o7c1fxJ2_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oA3v9CYh_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9x3KE4yr_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2TJ61AFX_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gWzObvec_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O1c8Kt3j_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3TIzdniJ_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xWrPFnXP_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mNrREZ7X_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IUwlfN7E_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VXjlQxSK_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0QzKyuj7_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HyrmMXVh_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WOISfsi9_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tUSj4xRn_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g1qsdEsi_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X2V4wATS_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nST7NwrE_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EQVetrNB_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2PFZpol9_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P7cuA8NF_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_MCt1eNOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dfp1DLgj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_EmXLAzoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F6jHrbc3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_7V4ZKRb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0aVwXfDy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_w9gmncr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJ9l0RS1_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LjdAYhXC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lWBc3aWY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NSLgc72H_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_Ued1osbx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CHvaXXn6, 0, m, &cSlice_CHvaXXn6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XIyMdBng_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_CHvaXXn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_o1kxGJ7c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_o1kxGJ7c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Lu7hLkQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_o1kxGJ7c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_o1kxGJ7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Uz8B1tCg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_eguJDk7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_S59jtLeE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qRmDSVTu, 0, m, &cIf_qRmDSVTu_sendMessage);
}

void Heavy_WSTD_EQ::cIf_qRmDSVTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EYkIWKUS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_x2rlqsFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3GQu4uKd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3l3XbX6k_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_JpxqevAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ML1b9Puz, HV_BINOP_POW, 0, m, &cBinop_ML1b9Puz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ML1b9Puz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dLdFr6NU, 0, m, &cIf_dLdFr6NU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W36lg329_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_KmzdO5jH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tR4nkRxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x2rlqsFn, 0, m, &cIf_x2rlqsFn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_apsz8tVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YDZ6YQ5S_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YDZ6YQ5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x2rlqsFn, 1, m, &cIf_x2rlqsFn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3l3XbX6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_W36lg329_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3GQu4uKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_dLdFr6NU, 0, m, &cIf_dLdFr6NU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KmzdO5jH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ML1b9Puz, HV_BINOP_POW, 1, m, &cBinop_ML1b9Puz_sendMessage);
  cMsg_JpxqevAj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_dLdFr6NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_wCWs1TP0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_S59jtLeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qRmDSVTu, 1, m, &cIf_qRmDSVTu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EYkIWKUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qght2VXl, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Qght2VXl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C6SPTL0f, HV_BINOP_EQ, 1, m, &cBinop_C6SPTL0f_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cwGYZVr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_M3p9RjFE, HV_BINOP_ADD, 0, m, &cBinop_M3p9RjFE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M3p9RjFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_apsz8tVQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tR4nkRxR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Qght2VXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dLdFr6NU, 1, m, &cIf_dLdFr6NU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_C6SPTL0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UInfozDm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_UInfozDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wCWs1TP0, m);
}

void Heavy_WSTD_EQ::cCast_YfIIfiE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eguJDk7U, 0, m, &cVar_eguJDk7U_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5fzrw2EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cwGYZVr1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_HEXK3t5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M3p9RjFE, HV_BINOP_ADD, 1, m, &cBinop_M3p9RjFE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qght2VXl, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Qght2VXl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C6SPTL0f, HV_BINOP_EQ, 0, m, &cBinop_C6SPTL0f_sendMessage);
}

void Heavy_WSTD_EQ::cVar_g649xj9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zCod6LGa_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_zZ7x4VvT, 0, m, &cIf_zZ7x4VvT_sendMessage);
}

void Heavy_WSTD_EQ::cIf_zZ7x4VvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aGkmOKJF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_tjd0DAya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LPTxCPZe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NJFM3csX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_KFHnJ91C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1jnVT4X8, HV_BINOP_POW, 0, m, &cBinop_1jnVT4X8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1jnVT4X8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WWSFjHjP, 0, m, &cIf_WWSFjHjP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uim3rZpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_RYaQUrBh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_B79UuABd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MVqdi03B_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iQwTuZmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tjd0DAya, 0, m, &cIf_tjd0DAya_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MVqdi03B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tjd0DAya, 1, m, &cIf_tjd0DAya_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NJFM3csX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uim3rZpk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_LPTxCPZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WWSFjHjP, 0, m, &cIf_WWSFjHjP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RYaQUrBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1jnVT4X8, HV_BINOP_POW, 1, m, &cBinop_1jnVT4X8_sendMessage);
  cMsg_KFHnJ91C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_WWSFjHjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3wK6O2ii_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dZ8gNZjK_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_xNod0mcp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_zCod6LGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zZ7x4VvT, 1, m, &cIf_zZ7x4VvT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aGkmOKJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ufwwsGL, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5ufwwsGL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C6mFOSQv, HV_BINOP_EQ, 1, m, &cBinop_C6mFOSQv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_K5IKs9x8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DnMdh2r1, HV_BINOP_ADD, 0, m, &cBinop_DnMdh2r1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DnMdh2r1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B79UuABd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iQwTuZmY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5ufwwsGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WWSFjHjP, 1, m, &cIf_WWSFjHjP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_C6mFOSQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uCFFQmHq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_uCFFQmHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3wK6O2ii_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dZ8gNZjK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_xNod0mcp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cYpKU399_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DnMdh2r1, HV_BINOP_ADD, 1, m, &cBinop_DnMdh2r1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ufwwsGL, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5ufwwsGL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C6mFOSQv, HV_BINOP_EQ, 0, m, &cBinop_C6mFOSQv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hNfzcEJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g649xj9b, 0, m, &cVar_g649xj9b_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XqrrW6rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K5IKs9x8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_C8LPgKDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nTA2Ja8m_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_O4cMsHgb, 0, m, &cIf_O4cMsHgb_sendMessage);
}

void Heavy_WSTD_EQ::cIf_O4cMsHgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4dNM3gpz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_If40ykhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_A5BeUsQ4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qbpb0r8Q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_ree5cTlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_07xsQ0O3, HV_BINOP_POW, 0, m, &cBinop_07xsQ0O3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_07xsQ0O3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yNae5tjz, 0, m, &cIf_yNae5tjz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sOTW9ylX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_RaGWgXW6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IDfIMGRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_If40ykhZ, 0, m, &cIf_If40ykhZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8kpXttAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LunYUGBL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LunYUGBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_If40ykhZ, 1, m, &cIf_If40ykhZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qbpb0r8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_sOTW9ylX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_A5BeUsQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_yNae5tjz, 0, m, &cIf_yNae5tjz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RaGWgXW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_07xsQ0O3, HV_BINOP_POW, 1, m, &cBinop_07xsQ0O3_sendMessage);
  cMsg_ree5cTlM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_yNae5tjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_HHYTZEoj, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_nTA2Ja8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O4cMsHgb, 1, m, &cIf_O4cMsHgb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4dNM3gpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tzcG5HEA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_tzcG5HEA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sVRlq0TA, HV_BINOP_EQ, 1, m, &cBinop_sVRlq0TA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8xvu4shx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hSTJPnZO, HV_BINOP_ADD, 0, m, &cBinop_hSTJPnZO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hSTJPnZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8kpXttAa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IDfIMGRR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tzcG5HEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yNae5tjz, 1, m, &cIf_yNae5tjz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sVRlq0TA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aEfZAGvU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_aEfZAGvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HHYTZEoj, m);
}

void Heavy_WSTD_EQ::cCast_G7vhMCb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8xvu4shx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_oytrQjko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hSTJPnZO, HV_BINOP_ADD, 1, m, &cBinop_hSTJPnZO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tzcG5HEA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_tzcG5HEA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sVRlq0TA, HV_BINOP_EQ, 0, m, &cBinop_sVRlq0TA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4bUIljzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C8LPgKDC, 0, m, &cVar_C8LPgKDC_sendMessage);
}

void Heavy_WSTD_EQ::cIf_4bleImbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qaedgNcM, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_s9Pj5Rvg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3OdPbKKU, 0, m, &cSlice_3OdPbKKU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oSfCLX0g_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_3OdPbKKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CE1tdyXu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CE1tdyXu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_TDpIw5pE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CE1tdyXu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_CE1tdyXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Qt5XWqfZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_oSfCLX0g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_A5LXP7IR, 0, m, &cSlice_A5LXP7IR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Ued1osbx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_A5LXP7IR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hlfZvk7g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hlfZvk7g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_4bCLSFyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hlfZvk7g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hlfZvk7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_B6WlgAmF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_XIyMdBng_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MVAlIBnO, 0, m, &cSlice_MVAlIBnO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WJwqthty_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_MVAlIBnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HD7K6GEu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HD7K6GEu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_yQHrDHTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HD7K6GEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_HD7K6GEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_44Q0ZM5T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_WJwqthty_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b4XvjEF6, 0, m, &cSlice_b4XvjEF6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_b4XvjEF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3Izv09YN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3Izv09YN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_h1F9CcER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3Izv09YN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_3Izv09YN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Xv8LyGyT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_IUH3r1Y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pgQQBMH1, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_vx61vz1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r6xiIwcH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_SXFtMYft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_knf87jTE, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_gTSQ7H1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jkX8pWd3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bQke2BZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L4RZ2g1F, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_WRTPqGXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ogD9ukWi_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_ogD9ukWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IZwr7tMO, HV_BINOP_DIVIDE, 1, m, &cBinop_IZwr7tMO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j7QtGvQT_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_84Q0nEwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ktMyW19N_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9gNXVRtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_84Q0nEwU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ktMyW19N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IZwr7tMO, HV_BINOP_DIVIDE, 0, m, &cBinop_IZwr7tMO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_j7QtGvQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9gNXVRtO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IZwr7tMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W6e3Eo0O, HV_BINOP_MULTIPLY, 1, m, &cBinop_W6e3Eo0O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W6e3Eo0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GRKCwlwW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wky58U50_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_5WAbE0bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9es1qZhn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_ZVcz86bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OY2feIdr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hQ0kANNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_7j8CLKaC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7j8CLKaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W6e3Eo0O, HV_BINOP_MULTIPLY, 0, m, &cBinop_W6e3Eo0O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oCs9jLpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ulBTkFBw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ulBTkFBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tzHgbS8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_SVNiR4KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_noypLz82, 1, m, &cVar_noypLz82_sendMessage);
}

void Heavy_WSTD_EQ::cVar_noypLz82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dyf9qrVM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_lOi8bf7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_szCw0xzK, HV_BINOP_MULTIPLY, 1, m, &cBinop_szCw0xzK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_H3B101N0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lOi8bf7Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_r90NGmIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iEWfHdrY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iEWfHdrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8xX5MOLP, HV_BINOP_MULTIPLY, 1, m, &cBinop_8xX5MOLP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ovTejgFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PKzh8Smd, HV_BINOP_MULTIPLY, 1, m, &cBinop_PKzh8Smd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_okmxx322_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ovTejgFg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_thhW0TXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F4uloD9d, HV_BINOP_MULTIPLY, 1, m, &cBinop_F4uloD9d_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_m3Q0qUFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ic9jgiY4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ic9jgiY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qf7Yg6Pg, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qf7Yg6Pg_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Mu76YY8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ngB0KmiQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_hQ0kANNn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OAtIhmLt_sendMessage);
}

void Heavy_WSTD_EQ::cVar_sFQ83uaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oCs9jLpL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Wky58U50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ZVcz86bl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GRKCwlwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5WAbE0bn_sendMessage);
}

void Heavy_WSTD_EQ::cSend_9es1qZhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XixLcU24_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_OY2feIdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_M6qVIi6e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_NKMk9OmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FZJ91Nqi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_tzHgbS8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cwkwWN6T_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cwkwWN6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_smK33ZPk, HV_BINOP_MULTIPLY, 1, m, &cBinop_smK33ZPk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_smK33ZPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_F5iCPMHn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F5iCPMHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NKMk9OmH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dyf9qrVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8jVLOcqK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8jVLOcqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jtJYltrp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_abwVx7Qg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wuEl8Xql_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dQKwAKZL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KMCYGLDl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pwlAq2In_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_szCw0xzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IUH3r1Y3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_8xX5MOLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vx61vz1D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_PKzh8Smd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SXFtMYft_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_F4uloD9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gTSQ7H1b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Qf7Yg6Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bQke2BZu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_eW3iui7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sFQ83uaE, 1, m, &cVar_sFQ83uaE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QetYCrpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mu76YY8J, 0, m, &cVar_Mu76YY8J_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dQKwAKZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PKzh8Smd, HV_BINOP_MULTIPLY, 0, m, &cBinop_PKzh8Smd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jtJYltrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_pwlAq2In_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_szCw0xzK, HV_BINOP_MULTIPLY, 0, m, &cBinop_szCw0xzK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wuEl8Xql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F4uloD9d, HV_BINOP_MULTIPLY, 0, m, &cBinop_F4uloD9d_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KMCYGLDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8xX5MOLP, HV_BINOP_MULTIPLY, 0, m, &cBinop_8xX5MOLP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_abwVx7Qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qf7Yg6Pg, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qf7Yg6Pg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OAtIhmLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_noypLz82, 0, m, &cVar_noypLz82_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ngB0KmiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sFQ83uaE, 0, m, &cVar_sFQ83uaE_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_s5MVwZHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u3t0R9xr, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_esvynVWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eLbD7VN0, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wmdd337A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hXm7kGbu, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_M3qTJSs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_laCV4pAV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_S6g9N9cY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oSPLUm8G_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_oSPLUm8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gf6MlPwl, HV_BINOP_DIVIDE, 1, m, &cBinop_gf6MlPwl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mZxLm10V_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Lum4cI0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_PZk4yHra_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Ede5nkZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Lum4cI0N_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PZk4yHra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gf6MlPwl, HV_BINOP_DIVIDE, 0, m, &cBinop_gf6MlPwl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mZxLm10V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ede5nkZu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gf6MlPwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z3IWqPji, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z3IWqPji_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z3IWqPji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WVtQ6bgF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gWxG3H99_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_whXueLo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Zh6vIgo0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_1v1yFzYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9B9Ntk1C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qqoCOMro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_PJxmJpQT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PJxmJpQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z3IWqPji, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z3IWqPji_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AAcQcADH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_NC6kyKWv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NC6kyKWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fTMqa8Zx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bIi8Ua57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o5vJum8z, HV_BINOP_MULTIPLY, 1, m, &cBinop_o5vJum8z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rO7WdfRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UwYHFfQK, 1, m, &cVar_UwYHFfQK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DJS7J870_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FLyOawQe, HV_BINOP_MULTIPLY, 1, m, &cBinop_FLyOawQe_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Hx72NTo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PHgECsya_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PHgECsya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UtJvQG8f, HV_BINOP_MULTIPLY, 1, m, &cBinop_UtJvQG8f_sendMessage);
}

void Heavy_WSTD_EQ::cVar_UwYHFfQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Y2dz6pA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_bWNw8mU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cgBNMeSG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_qqoCOMro_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IDy953eH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_kOWvWRSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_AAcQcADH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WVtQ6bgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_whXueLo0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gWxG3H99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_1v1yFzYU_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Zh6vIgo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9x3KE4yr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_9B9Ntk1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oA3v9CYh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_t0BIsob1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o7c1fxJ2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_fTMqa8Zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xNF3gcLg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xNF3gcLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L4doZIOO, HV_BINOP_MULTIPLY, 1, m, &cBinop_L4doZIOO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_L4doZIOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Hp01rg6O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hp01rg6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t0BIsob1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_8Y2dz6pA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pOnELfBG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pOnELfBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wMKWCOJI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hz7gA95o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y35QkgyY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EomT7Fkm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ahzZreHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s5MVwZHD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_o5vJum8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_esvynVWb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FLyOawQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wmdd337A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_UtJvQG8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M3qTJSs0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_grG3RZAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bWNw8mU6, 0, m, &cVar_bWNw8mU6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WTmLtXL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kOWvWRSi, 1, m, &cVar_kOWvWRSi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IDy953eH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UwYHFfQK, 0, m, &cVar_UwYHFfQK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cgBNMeSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kOWvWRSi, 0, m, &cVar_kOWvWRSi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wMKWCOJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UtJvQG8f, HV_BINOP_MULTIPLY, 0, m, &cBinop_UtJvQG8f_sendMessage);
}

void Heavy_WSTD_EQ::cCast_y35QkgyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o5vJum8z, HV_BINOP_MULTIPLY, 0, m, &cBinop_o5vJum8z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hz7gA95o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FLyOawQe, HV_BINOP_MULTIPLY, 0, m, &cBinop_FLyOawQe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EomT7Fkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ahzZreHB, HV_BINOP_MULTIPLY, 0, m, &cBinop_ahzZreHB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cV5cCtS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bTc7Mk7V, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_G4UYiRrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EiZU3hcH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_DvChQuxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mfqpsxFo, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_QodfdHS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QLYH2A29, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zILsXqA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qk89EJtr, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_cDBD4SYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6D1ATCFq_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_6D1ATCFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OXMWMxDC, HV_BINOP_DIVIDE, 1, m, &cBinop_OXMWMxDC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NveWIXLn_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_IgIwnHne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RVMWducb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_L6KLsOrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_IgIwnHne_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RVMWducb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OXMWMxDC, HV_BINOP_DIVIDE, 0, m, &cBinop_OXMWMxDC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NveWIXLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L6KLsOrQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_OXMWMxDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tAb0gqjt, HV_BINOP_MULTIPLY, 1, m, &cBinop_tAb0gqjt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tAb0gqjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Bq46fMC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZNfaTFIy_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_7PQVhklk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8fi1mahs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_ggS1VoWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1mVURbtO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gmQZvJHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9UmmQ0Mn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9UmmQ0Mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tAb0gqjt, HV_BINOP_MULTIPLY, 0, m, &cBinop_tAb0gqjt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qzgMkvk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8x2JO0qt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8x2JO0qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ufKFXk5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ta698wmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IvV2Rrve, HV_BINOP_MULTIPLY, 1, m, &cBinop_IvV2Rrve_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_pbp22mFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oCjNfcsI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oCjNfcsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ta698wmq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_c0NgEBPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QH2GaZzG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QH2GaZzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4M0tSsKy, HV_BINOP_MULTIPLY, 1, m, &cBinop_4M0tSsKy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QMdu7Qd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P6vh0uUd, HV_BINOP_MULTIPLY, 1, m, &cBinop_P6vh0uUd_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PbdzJRa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4c3Zrzsv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4c3Zrzsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QMdu7Qd9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oGo1nGLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9migpgiZ, 1, m, &cVar_9migpgiZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bOUOkGRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gi4fCoA0, HV_BINOP_MULTIPLY, 1, m, &cBinop_Gi4fCoA0_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SDJ8WT3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rbIiiP9c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rbIiiP9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1WgGiLuS, HV_BINOP_MULTIPLY, 1, m, &cBinop_1WgGiLuS_sendMessage);
}

void Heavy_WSTD_EQ::cVar_9migpgiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IWxB03S7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_xZPkSkz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n2NCr5Nq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_gmQZvJHU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dGbwvhm5_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ibNapkzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qzgMkvk1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8Bq46fMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_7PQVhklk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZNfaTFIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ggS1VoWT_sendMessage);
}

void Heavy_WSTD_EQ::cSend_8fi1mahs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O1c8Kt3j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_1mVURbtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gWzObvec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_7fxTbt6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2TJ61AFX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6ufKFXk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_elhwyX3o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_elhwyX3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JNhZwSDm, HV_BINOP_MULTIPLY, 1, m, &cBinop_JNhZwSDm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JNhZwSDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5gq9lttR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5gq9lttR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7fxTbt6v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_IWxB03S7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VRJjlXTj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VRJjlXTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DVdZ6fkD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kj9jaYbX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t3qWhUoL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uzPyWBSj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tydNPxP6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LtiECarO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IvV2Rrve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cV5cCtS9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4M0tSsKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G4UYiRrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_P6vh0uUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DvChQuxk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Gi4fCoA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QodfdHS6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1WgGiLuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zILsXqA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_paw4q5aF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xZPkSkz8, 0, m, &cVar_xZPkSkz8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Tjf84Cv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ibNapkzx, 1, m, &cVar_ibNapkzx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LtiECarO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IvV2Rrve, HV_BINOP_MULTIPLY, 0, m, &cBinop_IvV2Rrve_sendMessage);
}

void Heavy_WSTD_EQ::cCast_t3qWhUoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gi4fCoA0, HV_BINOP_MULTIPLY, 0, m, &cBinop_Gi4fCoA0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tydNPxP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4M0tSsKy, HV_BINOP_MULTIPLY, 0, m, &cBinop_4M0tSsKy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Kj9jaYbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1WgGiLuS, HV_BINOP_MULTIPLY, 0, m, &cBinop_1WgGiLuS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uzPyWBSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P6vh0uUd, HV_BINOP_MULTIPLY, 0, m, &cBinop_P6vh0uUd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DVdZ6fkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_n2NCr5Nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ibNapkzx, 0, m, &cVar_ibNapkzx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dGbwvhm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9migpgiZ, 0, m, &cVar_9migpgiZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3wK6O2ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4bleImbX, 1, m, &cIf_4bleImbX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9ewa27y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qaedgNcM, m);
}

void Heavy_WSTD_EQ::cBinop_dZ8gNZjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9ewa27y9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xNod0mcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4bleImbX, 0, m, &cIf_4bleImbX_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_ul6QYKz9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2LwgXpSY, 0, m, &cSlice_2LwgXpSY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_B7oP4RX9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_2LwgXpSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_G0U2k0LZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_G0U2k0LZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_i5SlIDFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G0U2k0LZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_G0U2k0LZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mNrREZ7X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_6n1ptZWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8pHIafrG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JTZ1IKB5, 0, m, &cIf_JTZ1IKB5_sendMessage);
}

void Heavy_WSTD_EQ::cIf_JTZ1IKB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_v2YLM6h5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_iMQXJMJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YcbpUTXS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_d5S0zB9W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_RVvEgI1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHx4wnkZ, HV_BINOP_POW, 0, m, &cBinop_RHx4wnkZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RHx4wnkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sglm63tX, 0, m, &cIf_Sglm63tX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SJbbdtvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CpDev5Jd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o2KAeLMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iMQXJMJD, 0, m, &cIf_iMQXJMJD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cYhJpWNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_l9q6fTCY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_l9q6fTCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iMQXJMJD, 1, m, &cIf_iMQXJMJD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_d5S0zB9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_SJbbdtvy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_YcbpUTXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Sglm63tX, 0, m, &cIf_Sglm63tX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CpDev5Jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHx4wnkZ, HV_BINOP_POW, 1, m, &cBinop_RHx4wnkZ_sendMessage);
  cMsg_RVvEgI1t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_Sglm63tX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qHnSMGpS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_8pHIafrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JTZ1IKB5, 1, m, &cIf_JTZ1IKB5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v2YLM6h5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OlNk12Bg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_OlNk12Bg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_akQu7LYv, HV_BINOP_EQ, 1, m, &cBinop_akQu7LYv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ButjbcKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6xe6JzxM, HV_BINOP_ADD, 0, m, &cBinop_6xe6JzxM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6xe6JzxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cYhJpWNk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o2KAeLMd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OlNk12Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sglm63tX, 1, m, &cIf_Sglm63tX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_akQu7LYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hOW9wh6H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hOW9wh6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qHnSMGpS, m);
}

void Heavy_WSTD_EQ::cCast_RFGZDtgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ButjbcKI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_FR1Umxle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6xe6JzxM, HV_BINOP_ADD, 1, m, &cBinop_6xe6JzxM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OlNk12Bg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_OlNk12Bg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_akQu7LYv, HV_BINOP_EQ, 0, m, &cBinop_akQu7LYv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QmCRSzeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6n1ptZWV, 0, m, &cVar_6n1ptZWV_sendMessage);
}

void Heavy_WSTD_EQ::cVar_2scni3eZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tdKkTL7N_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_9cuno8xQ, 0, m, &cIf_9cuno8xQ_sendMessage);
}

void Heavy_WSTD_EQ::cIf_9cuno8xQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_exsayOmx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_9WifW4f4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_roc9Kbeb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0Q0QUnJW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_g9OQVF2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6cBfTcEU, HV_BINOP_POW, 0, m, &cBinop_6cBfTcEU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6cBfTcEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Fmj0pWp, 0, m, &cIf_5Fmj0pWp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kWBMHcXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_syfmOWEJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ucwt6cVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_k6Y85uDn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ADlKmKMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9WifW4f4, 0, m, &cIf_9WifW4f4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k6Y85uDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9WifW4f4, 1, m, &cIf_9WifW4f4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0Q0QUnJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kWBMHcXi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_roc9Kbeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5Fmj0pWp, 0, m, &cIf_5Fmj0pWp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_syfmOWEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6cBfTcEU, HV_BINOP_POW, 1, m, &cBinop_6cBfTcEU_sendMessage);
  cMsg_g9OQVF2W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_5Fmj0pWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IVdvziQD_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yv8YMCME_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_5bWA2RgZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_tdKkTL7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9cuno8xQ, 1, m, &cIf_9cuno8xQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_exsayOmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5KuNCxM6, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5KuNCxM6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_98Sf69L1, HV_BINOP_EQ, 1, m, &cBinop_98Sf69L1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_0sVLPEJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_twajeKBV, HV_BINOP_ADD, 0, m, &cBinop_twajeKBV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_twajeKBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ucwt6cVh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ADlKmKMS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5KuNCxM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Fmj0pWp, 1, m, &cIf_5Fmj0pWp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_98Sf69L1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S11Sq86Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_S11Sq86Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IVdvziQD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yv8YMCME_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_5bWA2RgZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_P8Puzn47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2scni3eZ, 0, m, &cVar_2scni3eZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dSuFpHIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0sVLPEJf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_g8obLLTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_twajeKBV, HV_BINOP_ADD, 1, m, &cBinop_twajeKBV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5KuNCxM6, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5KuNCxM6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_98Sf69L1, HV_BINOP_EQ, 0, m, &cBinop_98Sf69L1_sendMessage);
}

void Heavy_WSTD_EQ::cVar_WCwaKddX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4z53bMMx_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_o2pWlvXe, 0, m, &cIf_o2pWlvXe_sendMessage);
}

void Heavy_WSTD_EQ::cIf_o2pWlvXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_INhmreY7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_xSoyV3Hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_gTlZbC3h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_s0wNSLqm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_wnd1rofi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhUemtNy, HV_BINOP_POW, 0, m, &cBinop_dhUemtNy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dhUemtNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ww9a1e2m, 0, m, &cIf_Ww9a1e2m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TIHm8NIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_bQSbnWMO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Qob8qhzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xSoyV3Hd, 0, m, &cIf_xSoyV3Hd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7WYzPY8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8Zs5RdFO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8Zs5RdFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xSoyV3Hd, 1, m, &cIf_xSoyV3Hd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_s0wNSLqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TIHm8NIx_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_gTlZbC3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Ww9a1e2m, 0, m, &cIf_Ww9a1e2m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bQSbnWMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhUemtNy, HV_BINOP_POW, 1, m, &cBinop_dhUemtNy_sendMessage);
  cMsg_wnd1rofi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_Ww9a1e2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_eKImh4nO, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_4z53bMMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o2pWlvXe, 1, m, &cIf_o2pWlvXe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_INhmreY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_voXTA9H7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_voXTA9H7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pync9tSR, HV_BINOP_EQ, 1, m, &cBinop_pync9tSR_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_aWmEW933_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AQUWLiF2, HV_BINOP_ADD, 0, m, &cBinop_AQUWLiF2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AQUWLiF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7WYzPY8A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qob8qhzz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_voXTA9H7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ww9a1e2m, 1, m, &cIf_Ww9a1e2m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pync9tSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XOk9lZoe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_XOk9lZoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eKImh4nO, m);
}

void Heavy_WSTD_EQ::cCast_CmOeu0aS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WCwaKddX, 0, m, &cVar_WCwaKddX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_T1uoPUzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aWmEW933_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_spV4zaQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AQUWLiF2, HV_BINOP_ADD, 1, m, &cBinop_AQUWLiF2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_voXTA9H7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_voXTA9H7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pync9tSR, HV_BINOP_EQ, 0, m, &cBinop_pync9tSR_sendMessage);
}

void Heavy_WSTD_EQ::cIf_1iP3jMtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Lzx28c4B, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_ET9V8t2n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_20wNMU4B, 0, m, &cSlice_20wNMU4B_sendMessage);
      break;
    }
    default: {
      cSwitchcase_v9pPmzoX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_20wNMU4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dkDxFYUo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dkDxFYUo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_OqfnMYBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dkDxFYUo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_dkDxFYUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3TIzdniJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_v9pPmzoX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M3ZerbGm, 0, m, &cSlice_M3ZerbGm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ul6QYKz9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_M3ZerbGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_s36vaIsF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_s36vaIsF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_BPhwZmBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s36vaIsF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_s36vaIsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VXjlQxSK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_B7oP4RX9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_o92EDTVB, 0, m, &cSlice_o92EDTVB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HNGv5Ty1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_o92EDTVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3Nuh3SOF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3Nuh3SOF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_3YjHqHI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3Nuh3SOF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_3Nuh3SOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xWrPFnXP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_HNGv5Ty1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ehAQ7LRY, 0, m, &cSlice_ehAQ7LRY_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ehAQ7LRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V7fm0Wqn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V7fm0Wqn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_wJPEZOyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V7fm0Wqn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_V7fm0Wqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IUwlfN7E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_9K6L0IXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_doXSiWGJ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_SJMGHCpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3oG0g0JV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JAgsWxMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yyJeHcEf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Blo1iSJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yDwuL3KH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_4l982FSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XolpV6U9, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_uBSS2XWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Mwe8hHal_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Mwe8hHal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pNLIwXU3, HV_BINOP_DIVIDE, 1, m, &cBinop_pNLIwXU3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_is2R2ysG_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Wtq38Jfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_oyf19TSz_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Qpoz1FcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Wtq38Jfp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oyf19TSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pNLIwXU3, HV_BINOP_DIVIDE, 0, m, &cBinop_pNLIwXU3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_is2R2ysG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qpoz1FcE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pNLIwXU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tj45sKgl, HV_BINOP_MULTIPLY, 1, m, &cBinop_Tj45sKgl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Tj45sKgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PPhVPuVB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qTPBWvD0_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_CgYMEonz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XT9557qb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_D60M37za_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JTLElthr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_QLFfMvzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6lFpXUr5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6lFpXUr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tj45sKgl, HV_BINOP_MULTIPLY, 0, m, &cBinop_Tj45sKgl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3IQJwOYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_TOzlB9zO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TOzlB9zO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CBNm1D3X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bJM9ku1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6DgZizDj, 1, m, &cVar_6DgZizDj_sendMessage);
}

void Heavy_WSTD_EQ::cVar_6DgZizDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NkyXPQ4s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_YXlIdWLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vG5wqtPa, HV_BINOP_MULTIPLY, 1, m, &cBinop_vG5wqtPa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lHR2RaGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YXlIdWLo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TU7ZtCr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VnJEuoBJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VnJEuoBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqgp1Hbf, HV_BINOP_MULTIPLY, 1, m, &cBinop_aqgp1Hbf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WrBP4Y6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DV5zqde0, HV_BINOP_MULTIPLY, 1, m, &cBinop_DV5zqde0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dZTfQpTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WrBP4Y6L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qBr0ZQF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JnJ7qzWA, HV_BINOP_MULTIPLY, 1, m, &cBinop_JnJ7qzWA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_F3MvYVau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NeTm1lzK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NeTm1lzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzvpsBRu, HV_BINOP_MULTIPLY, 1, m, &cBinop_HzvpsBRu_sendMessage);
}

void Heavy_WSTD_EQ::cVar_DyalfqH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eqpsCsQg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_QLFfMvzL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zgiVoHRH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_AyHfsWdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3IQJwOYo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qTPBWvD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_D60M37za_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PPhVPuVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_CgYMEonz_sendMessage);
}

void Heavy_WSTD_EQ::cSend_XT9557qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WOISfsi9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_JTLElthr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HyrmMXVh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bzr6qJHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0QzKyuj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_CBNm1D3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cIZ5p8T6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cIZ5p8T6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_he52eyoA, HV_BINOP_MULTIPLY, 1, m, &cBinop_he52eyoA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_he52eyoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_luxA17G8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_luxA17G8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bzr6qJHt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_NkyXPQ4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PhFfDImX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PhFfDImX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4b1jKPKp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GJ6yu2Ss_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WXFcTegE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zJaYLo8t_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pro0Vobo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hm1Rlx1a_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vG5wqtPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9K6L0IXh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_aqgp1Hbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SJMGHCpv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DV5zqde0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JAgsWxMT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JnJ7qzWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Blo1iSJv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HzvpsBRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4l982FSI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_WStABlMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AyHfsWdy, 1, m, &cVar_AyHfsWdy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6GKJKxCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DyalfqH1, 0, m, &cVar_DyalfqH1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Pro0Vobo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqgp1Hbf, HV_BINOP_MULTIPLY, 0, m, &cBinop_aqgp1Hbf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GJ6yu2Ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzvpsBRu, HV_BINOP_MULTIPLY, 0, m, &cBinop_HzvpsBRu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zJaYLo8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DV5zqde0, HV_BINOP_MULTIPLY, 0, m, &cBinop_DV5zqde0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4b1jKPKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_hm1Rlx1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vG5wqtPa, HV_BINOP_MULTIPLY, 0, m, &cBinop_vG5wqtPa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WXFcTegE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JnJ7qzWA, HV_BINOP_MULTIPLY, 0, m, &cBinop_JnJ7qzWA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zgiVoHRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6DgZizDj, 0, m, &cVar_6DgZizDj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eqpsCsQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AyHfsWdy, 0, m, &cVar_AyHfsWdy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_M4OqL4ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nWumo2KL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JUdpcGWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4UfskI8D, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ycRXuube_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1RvMZ9WL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_NuLZHSgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AaYjNJdF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_yGkQMEJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fz85ZR8l_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_fz85ZR8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGIxSVFf, HV_BINOP_DIVIDE, 1, m, &cBinop_AGIxSVFf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QGysqANR_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_HAMcR7DU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_3qRDaBcg_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wgID9Q00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_HAMcR7DU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3qRDaBcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGIxSVFf, HV_BINOP_DIVIDE, 0, m, &cBinop_AGIxSVFf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QGysqANR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wgID9Q00_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_AGIxSVFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5U1OEPsD, HV_BINOP_MULTIPLY, 1, m, &cBinop_5U1OEPsD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5U1OEPsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OEKg4ZMV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aGhQqfWh_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_PNjhWMVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RBF5SVAH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_SS4MzIdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pNfINrWG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_eWr6TIsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_kCbH2MXd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kCbH2MXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5U1OEPsD, HV_BINOP_MULTIPLY, 0, m, &cBinop_5U1OEPsD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UwrOZwO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_94JpsZbd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_94JpsZbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6GNB6Owk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6HVVBZN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVQuTqqm, HV_BINOP_MULTIPLY, 1, m, &cBinop_mVQuTqqm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PHLmQFA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yavj0bIj, 1, m, &cVar_yavj0bIj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_82yXtScm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OlFtt4Ed, HV_BINOP_MULTIPLY, 1, m, &cBinop_OlFtt4Ed_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Py2B8oN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ACWcDcJa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ACWcDcJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xf5dnuZy, HV_BINOP_MULTIPLY, 1, m, &cBinop_xf5dnuZy_sendMessage);
}

void Heavy_WSTD_EQ::cVar_yavj0bIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LfK3fjCN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_xtlgIGhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s06HyyhY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_eWr6TIsq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uH4shFSR_sendMessage);
}

void Heavy_WSTD_EQ::cVar_rbtlhECx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_UwrOZwO0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aGhQqfWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SS4MzIdU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OEKg4ZMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_PNjhWMVz_sendMessage);
}

void Heavy_WSTD_EQ::cSend_RBF5SVAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_X2V4wATS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_pNfINrWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_g1qsdEsi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Fj09nh3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tUSj4xRn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6GNB6Owk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8ugEX6Fw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8ugEX6Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D9sNzMbM, HV_BINOP_MULTIPLY, 1, m, &cBinop_D9sNzMbM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_D9sNzMbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_scBa1ahB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_scBa1ahB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Fj09nh3U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_LfK3fjCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iKLgb07M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iKLgb07M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6MHWaRcj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ETNSNvCW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1j0vkMGZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mczD6lIC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AxddfZ9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M4OqL4ic_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mVQuTqqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JUdpcGWg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_OlFtt4Ed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ycRXuube_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xf5dnuZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NuLZHSgW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_JdlFCsfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xtlgIGhj, 0, m, &cVar_xtlgIGhj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rowX8NdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rbtlhECx, 1, m, &cVar_rbtlhECx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uH4shFSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yavj0bIj, 0, m, &cVar_yavj0bIj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_s06HyyhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rbtlhECx, 0, m, &cVar_rbtlhECx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6MHWaRcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xf5dnuZy, HV_BINOP_MULTIPLY, 0, m, &cBinop_xf5dnuZy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1j0vkMGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVQuTqqm, HV_BINOP_MULTIPLY, 0, m, &cBinop_mVQuTqqm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ETNSNvCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OlFtt4Ed, HV_BINOP_MULTIPLY, 0, m, &cBinop_OlFtt4Ed_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mczD6lIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AxddfZ9c, HV_BINOP_MULTIPLY, 0, m, &cBinop_AxddfZ9c_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8Ty0f5sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vRIIGk8F, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_SrtTZPab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_me9udPJU, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_MFvw7s47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iamKpxWx, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kRjr5QcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ktZ6RwQF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_HlhGoBAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HTRSDykD, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_lZcqsGo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eVTeAKff_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_eVTeAKff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zN5Ekav1, HV_BINOP_DIVIDE, 1, m, &cBinop_zN5Ekav1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WIartZW9_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_PVzbzDCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_8vZy5LTu_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_w6oaRhIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_PVzbzDCQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8vZy5LTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zN5Ekav1, HV_BINOP_DIVIDE, 0, m, &cBinop_zN5Ekav1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WIartZW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w6oaRhIB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zN5Ekav1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iUg9XnRW, HV_BINOP_MULTIPLY, 1, m, &cBinop_iUg9XnRW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iUg9XnRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pFM0GBGb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fQnjgvmO_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ENQNBbCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_35ci5R7Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_huIq7Q6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vJQwOwxF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ZZf0reAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_i38YuzND_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_i38YuzND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iUg9XnRW, HV_BINOP_MULTIPLY, 0, m, &cBinop_iUg9XnRW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ahh2pa20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_OAS48UND_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OAS48UND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ojj5ChFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wA0kOFoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8jPS2AjS, HV_BINOP_MULTIPLY, 1, m, &cBinop_8jPS2AjS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_l3hcsEwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pzT1TJpw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pzT1TJpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wA0kOFoa_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lxxYYLIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fBfwri5s_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fBfwri5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JwLRJIaT, HV_BINOP_MULTIPLY, 1, m, &cBinop_JwLRJIaT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ODwWcLRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vb1ZLfW7, HV_BINOP_MULTIPLY, 1, m, &cBinop_Vb1ZLfW7_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_az4wfEwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qPPk37NN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qPPk37NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ODwWcLRq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5ElyB4L1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mV6cF0O5, 1, m, &cVar_mV6cF0O5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Y55NAcEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uxYd9p29, HV_BINOP_MULTIPLY, 1, m, &cBinop_uxYd9p29_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_F0KbgIKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_p84ojCv6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p84ojCv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLZXQbzQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_lLZXQbzQ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_mV6cF0O5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ncl7HA05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_xRDoULzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T9MkDZYd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ZZf0reAk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cJ1Mja9X_sendMessage);
}

void Heavy_WSTD_EQ::cVar_pP9sFdnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ahh2pa20_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pFM0GBGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ENQNBbCm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fQnjgvmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_huIq7Q6W_sendMessage);
}

void Heavy_WSTD_EQ::cSend_35ci5R7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2PFZpol9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_vJQwOwxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EQVetrNB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_WzwgyqxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nST7NwrE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Ojj5ChFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DIvPdGgA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DIvPdGgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FTbHIHeA, HV_BINOP_MULTIPLY, 1, m, &cBinop_FTbHIHeA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FTbHIHeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6hpqstFx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6hpqstFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WzwgyqxJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ncl7HA05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_baVxFUhW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_baVxFUhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MqjovD53_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q93CMOmE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vgK0AMQR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nVaw3lDp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4LgyNVq5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4YJ2XG0J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8jPS2AjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Ty0f5sg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JwLRJIaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SrtTZPab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Vb1ZLfW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MFvw7s47_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uxYd9p29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kRjr5QcF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_lLZXQbzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HlhGoBAu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_fviZoMCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xRDoULzp, 0, m, &cVar_xRDoULzp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iqr5wKNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pP9sFdnL, 1, m, &cVar_pP9sFdnL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4LgyNVq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JwLRJIaT, HV_BINOP_MULTIPLY, 0, m, &cBinop_JwLRJIaT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vgK0AMQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uxYd9p29, HV_BINOP_MULTIPLY, 0, m, &cBinop_uxYd9p29_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nVaw3lDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vb1ZLfW7, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vb1ZLfW7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_q93CMOmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLZXQbzQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_lLZXQbzQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4YJ2XG0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8jPS2AjS, HV_BINOP_MULTIPLY, 0, m, &cBinop_8jPS2AjS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MqjovD53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_T9MkDZYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pP9sFdnL, 0, m, &cVar_pP9sFdnL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cJ1Mja9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mV6cF0O5, 0, m, &cVar_mV6cF0O5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IVdvziQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1iP3jMtq, 1, m, &cIf_1iP3jMtq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FSkf5zXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Lzx28c4B, m);
}

void Heavy_WSTD_EQ::cBinop_yv8YMCME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FSkf5zXi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5bWA2RgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1iP3jMtq, 0, m, &cIf_1iP3jMtq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_taECnX9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5WtEBxwy, HV_BINOP_DIVIDE, 0, m, &cBinop_5WtEBxwy_sendMessage);
}

void Heavy_WSTD_EQ::cVar_d7HZyxUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_89llZr5m, HV_BINOP_DIVIDE, 1, m, &cBinop_89llZr5m_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5WtEBxwy, HV_BINOP_DIVIDE, 1, m, &cBinop_5WtEBxwy_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_cZ5DXqYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_89cx69PA, HV_BINOP_DIVIDE, 0, m, &cBinop_89cx69PA_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_xyiUTJXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_89cx69PA, HV_BINOP_DIVIDE, 1, m, &cBinop_89cx69PA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LjdAYhXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d7HZyxUB, 0, m, &cVar_d7HZyxUB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NSLgc72H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_89llZr5m, HV_BINOP_DIVIDE, 0, m, &cBinop_89llZr5m_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lWBc3aWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_taECnX9N, 0, m, &cVar_taECnX9N_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_89llZr5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_cZ5DXqYY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5WtEBxwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_xyiUTJXB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_89cx69PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_kT5owaMj_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_OX4QiFIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_JBRoY43W_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qaD9Lnjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_DEtwM8ay_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kT5owaMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qaD9Lnjd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DEtwM8ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_OX4QiFIq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JBRoY43W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s8NKbcQw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dfp1DLgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_s9Pj5Rvg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ET9V8t2n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_F6jHrbc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_s9Pj5Rvg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ET9V8t2n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0aVwXfDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_s9Pj5Rvg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ET9V8t2n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CJ9l0RS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_s9Pj5Rvg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ET9V8t2n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_s8NKbcQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_s9Pj5Rvg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ET9V8t2n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_RNKu9GQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_w9gmncr6, 0, m, &cVar_w9gmncr6_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lm40okWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_MCt1eNOB, 0, m, &cVar_MCt1eNOB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EmXLAzoM, 0, m, &cVar_EmXLAzoM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7V4ZKRb3, 0, m, &cVar_7V4ZKRb3_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_88EN9vcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MCt1eNOB, 0, m, &cVar_MCt1eNOB_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_6yvLC2Iw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EmXLAzoM, 0, m, &cVar_EmXLAzoM_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_8kb5FU9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7V4ZKRb3, 0, m, &cVar_7V4ZKRb3_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Uz8B1tCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bWNw8mU6, 0, m, &cVar_bWNw8mU6_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Xv8LyGyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WTmLtXL2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_grG3RZAp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Qt5XWqfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YfIIfiE9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HEXK3t5J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5fzrw2EJ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_44Q0ZM5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4bUIljzN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oytrQjko_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G7vhMCb8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_B6WlgAmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hNfzcEJ9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cYpKU399_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XqrrW6rp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_P7cuA8NF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WRTPqGXc_sendMessage(_c, 0, m);
  cMsg_S6g9N9cY_sendMessage(_c, 0, m);
  cMsg_cDBD4SYR_sendMessage(_c, 0, m);
  cMsg_uBSS2XWQ_sendMessage(_c, 0, m);
  cMsg_yGkQMEJu_sendMessage(_c, 0, m);
  cMsg_lZcqsGo6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Mu76YY8J, 0, m, &cVar_Mu76YY8J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bWNw8mU6, 0, m, &cVar_bWNw8mU6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xZPkSkz8, 0, m, &cVar_xZPkSkz8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DyalfqH1, 0, m, &cVar_DyalfqH1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xtlgIGhj, 0, m, &cVar_xtlgIGhj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xRDoULzp, 0, m, &cVar_xRDoULzp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Lu7hLkQQ, 0, m, &cVar_Lu7hLkQQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eguJDk7U, 0, m, &cVar_eguJDk7U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_g649xj9b, 0, m, &cVar_g649xj9b_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C8LPgKDC, 0, m, &cVar_C8LPgKDC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TDpIw5pE, 0, m, &cVar_TDpIw5pE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4bCLSFyI, 0, m, &cVar_4bCLSFyI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yQHrDHTI, 0, m, &cVar_yQHrDHTI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_h1F9CcER, 0, m, &cVar_h1F9CcER_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i5SlIDFm, 0, m, &cVar_i5SlIDFm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6n1ptZWV, 0, m, &cVar_6n1ptZWV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2scni3eZ, 0, m, &cVar_2scni3eZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WCwaKddX, 0, m, &cVar_WCwaKddX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OqfnMYBG, 0, m, &cVar_OqfnMYBG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BPhwZmBm, 0, m, &cVar_BPhwZmBm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3YjHqHI1, 0, m, &cVar_3YjHqHI1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wJPEZOyG, 0, m, &cVar_wJPEZOyG_sendMessage);
  cMsg_lm40okWc_sendMessage(_c, 0, m);
  cMsg_RNKu9GQH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_XixLcU24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_smK33ZPk, HV_BINOP_MULTIPLY, 0, m, &cBinop_smK33ZPk_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_M6qVIi6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_H3B101N0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_r90NGmIy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_okmxx322_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_thhW0TXk_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_FZJ91Nqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SVNiR4KG_sendMessage);
  cMsg_m3Q0qUFI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_9x3KE4yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L4doZIOO, HV_BINOP_MULTIPLY, 0, m, &cBinop_L4doZIOO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_oA3v9CYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_DJS7J870_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_o7c1fxJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ahzZreHB, HV_BINOP_MULTIPLY, 1, m, &cBinop_ahzZreHB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bIi8Ua57_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rO7WdfRM_sendMessage);
  cMsg_Hx72NTo5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_O1c8Kt3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JNhZwSDm, HV_BINOP_MULTIPLY, 0, m, &cBinop_JNhZwSDm_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_gWzObvec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pbp22mFc_sendMessage(_c, 0, m);
  cMsg_c0NgEBPX_sendMessage(_c, 0, m);
  cMsg_PbdzJRa4_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bOUOkGRN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_2TJ61AFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oGo1nGLj_sendMessage);
  cMsg_SDJ8WT3O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_mNrREZ7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xtlgIGhj, 0, m, &cVar_xtlgIGhj_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_IUwlfN7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rowX8NdU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdlFCsfH_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_3TIzdniJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QmCRSzeT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FR1Umxle_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RFGZDtgM_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_xWrPFnXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CmOeu0aS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_spV4zaQz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T1uoPUzv_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_VXjlQxSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8Puzn47_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g8obLLTM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dSuFpHIP_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_WOISfsi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_he52eyoA, HV_BINOP_MULTIPLY, 0, m, &cBinop_he52eyoA_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_HyrmMXVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lHR2RaGG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TU7ZtCr5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dZTfQpTr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_qBr0ZQF7_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0QzKyuj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bJM9ku1p_sendMessage);
  cMsg_F3MvYVau_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_X2V4wATS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D9sNzMbM, HV_BINOP_MULTIPLY, 0, m, &cBinop_D9sNzMbM_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_g1qsdEsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_82yXtScm_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_tUSj4xRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AxddfZ9c, HV_BINOP_MULTIPLY, 1, m, &cBinop_AxddfZ9c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6HVVBZN5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PHLmQFA7_sendMessage);
  cMsg_Py2B8oN6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_2PFZpol9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FTbHIHeA, HV_BINOP_MULTIPLY, 0, m, &cBinop_FTbHIHeA_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_EQVetrNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l3hcsEwC_sendMessage(_c, 0, m);
  cMsg_lxxYYLIm_sendMessage(_c, 0, m);
  cMsg_az4wfEwX_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Y55NAcEn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_nST7NwrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5ElyB4L1_sendMessage);
  cMsg_F0KbgIKg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_FcnzVrtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w9gmncr6, 0, m, &cVar_w9gmncr6_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_dS0GJuSZ, VOf(Bf0));
    __hv_varread_f(&sVarf_xF0n5O8G, VOf(Bf1));
    __hv_varread_f(&sVarf_ZtKBZZCO, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_9fPTsxO3, VOf(Bf0));
    __hv_varread_f(&sVarf_2sUXdkIQ, VOf(Bf1));
    __hv_varread_f(&sVarf_UWQ3dLgE, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_pgQQBMH1, VOf(Bf0));
    __hv_line_f(&sLine_r6xiIwcH, VOf(Bf1));
    __hv_line_f(&sLine_knf87jTE, VOf(Bf4));
    __hv_line_f(&sLine_jkX8pWd3, VOf(Bf5));
    __hv_line_f(&sLine_L4RZ2g1F, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_jC0mNb1o, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_wCWs1TP0, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_u3t0R9xr, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_eLbD7VN0, VOf(Bf1));
    __hv_line_f(&sLine_hXm7kGbu, VOf(Bf0));
    __hv_line_f(&sLine_laCV4pAV, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_4ucADfyy, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_qaedgNcM, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_bTc7Mk7V, VOf(Bf7));
    __hv_line_f(&sLine_EiZU3hcH, VOf(Bf1));
    __hv_line_f(&sLine_mfqpsxFo, VOf(Bf4));
    __hv_line_f(&sLine_QLYH2A29, VOf(Bf6));
    __hv_line_f(&sLine_qk89EJtr, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_gE3cUscl, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_HHYTZEoj, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_dS0GJuSZ, VIf(Bf5));
    __hv_varwrite_f(&sVarf_xF0n5O8G, VIf(Bf0));
    __hv_varwrite_f(&sVarf_ZtKBZZCO, VIf(Bf6));
    __hv_line_f(&sLine_doXSiWGJ, VOf(Bf6));
    __hv_line_f(&sLine_3oG0g0JV, VOf(Bf0));
    __hv_line_f(&sLine_yyJeHcEf, VOf(Bf5));
    __hv_line_f(&sLine_yDwuL3KH, VOf(Bf8));
    __hv_line_f(&sLine_XolpV6U9, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_vlkzHD5M, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_qHnSMGpS, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_nWumo2KL, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_4UfskI8D, VOf(Bf0));
    __hv_line_f(&sLine_1RvMZ9WL, VOf(Bf6));
    __hv_line_f(&sLine_AaYjNJdF, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_EsqsyHhA, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Lzx28c4B, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_vRIIGk8F, VOf(Bf1));
    __hv_line_f(&sLine_me9udPJU, VOf(Bf0));
    __hv_line_f(&sLine_iamKpxWx, VOf(Bf5));
    __hv_line_f(&sLine_ktZ6RwQF, VOf(Bf4));
    __hv_line_f(&sLine_HTRSDykD, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_90m0DUGd, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_eKImh4nO, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_9fPTsxO3, VIf(Bf8));
    __hv_varwrite_f(&sVarf_2sUXdkIQ, VIf(Bf6));
    __hv_varwrite_f(&sVarf_UWQ3dLgE, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
